# !/usr/bin/env python
# -*-coding:utf-8 -*-

"""
# File       : customVar.py
# Time       ：22/3/10 15:26
# Author     ：Lex
# email      : 2983997560@qq.com
# Description：自定义数据类型
"""
from .dmE import *
from .thread import MyThread


class CustomE:
    def __init__(self):
        self.dm = tmp
        self.thread = MyThread()
        self.hwnd = None
        self.title = None
        self.account = None
        self.password = None
        self.service = None
        self.task_list = None
        self.progress = None

    def clear(self):
        pass
